Module: Google::Cloud::Orchestration::Airflow::Service
- Defined in:
- lib/google/cloud/orchestration/airflow/service.rb,
lib/google/cloud/orchestration/airflow/service/version.rb
Constant Summary collapse
- VERSION =
"1.7.0"
Class Method Summary collapse
-
.configure {|::Google::Cloud.configure.orchestration_airflow_service| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-orchestration-airflow-service library.
-
.environments(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for Environments.
-
.environments_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the Environments service is supported by the current client.
-
.image_versions(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for ImageVersions.
-
.image_versions_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the ImageVersions service is supported by the current client.
Class Method Details
.configure {|::Google::Cloud.configure.orchestration_airflow_service| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-orchestration-airflow-service library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:jitter(type:Numeric) - The jitter in seconds. Default: 1.0.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
219 220 221 222 223 |
# File 'lib/google/cloud/orchestration/airflow/service.rb', line 219 def self.configure yield ::Google::Cloud.configure.orchestration_airflow_service if block_given? ::Google::Cloud.configure.orchestration_airflow_service end |
.environments(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for Environments.
By default, this returns an instance of
Google::Cloud::Orchestration::Airflow::Service::V1::Environments::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the Environments service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the Environments service. You can determine whether the method will succeed by calling environments_available?.
About Environments
Managed Apache Airflow Environments.
77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/google/cloud/orchestration/airflow/service.rb', line 77 def self.environments version: :v1, transport: :grpc, &block require "google/cloud/orchestration/airflow/service/#{version.to_s.downcase}" package_name = Google::Cloud::Orchestration::Airflow::Service .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Orchestration::Airflow::Service.const_get(package_name).const_get(:Environments) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.environments_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the Environments service is supported by the current client. If true, you can retrieve a client object by calling environments. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the Environments service, or if the versioned client gem needs an update to support the Environments service.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/google/cloud/orchestration/airflow/service.rb', line 101 def self.environments_available? version: :v1, transport: :grpc require "google/cloud/orchestration/airflow/service/#{version.to_s.downcase}" package_name = Google::Cloud::Orchestration::Airflow::Service .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::Orchestration::Airflow::Service.const_get package_name return false unless service_module.const_defined? :Environments service_module = service_module.const_get :Environments if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.image_versions(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for ImageVersions.
By default, this returns an instance of
Google::Cloud::Orchestration::Airflow::Service::V1::ImageVersions::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the ImageVersions service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the ImageVersions service. You can determine whether the method will succeed by calling image_versions_available?.
About ImageVersions
Readonly service to query available ImageVersions.
147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/google/cloud/orchestration/airflow/service.rb', line 147 def self.image_versions version: :v1, transport: :grpc, &block require "google/cloud/orchestration/airflow/service/#{version.to_s.downcase}" package_name = Google::Cloud::Orchestration::Airflow::Service .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Orchestration::Airflow::Service.const_get(package_name).const_get(:ImageVersions) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.image_versions_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the ImageVersions service is supported by the current client. If true, you can retrieve a client object by calling image_versions. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the ImageVersions service, or if the versioned client gem needs an update to support the ImageVersions service.
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/google/cloud/orchestration/airflow/service.rb', line 171 def self.image_versions_available? version: :v1, transport: :grpc require "google/cloud/orchestration/airflow/service/#{version.to_s.downcase}" package_name = Google::Cloud::Orchestration::Airflow::Service .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::Orchestration::Airflow::Service.const_get package_name return false unless service_module.const_defined? :ImageVersions service_module = service_module.const_get :ImageVersions if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |